@@ -6,11 +6,11 @@
 #
 # This is free software; you can do what the LICENCE file allows you to.
 #
+from collections.abc import Mapping
+from functools import partial
 from typing import Type
 
 import immutables
-from collections.abc import Mapping
-from functools import partial
 
 from .pickablenv import PickableRecordset
 
@@ -47,7 +47,7 @@ class ImmutableWrapper:
        >>> assert new.start_date == target.start_date + timedelta(1)           # doctest: +SKIP
 
     Immutable wrappers are always flattened.  If the `target` object is
-    another instance of ImmutableWrapper, we extracts its enclosed object and
+    another instance of ImmutableWrapper, we extract its enclosed object and
     "inherit" the overrides:
 
     .. code-block:: python
@@ -81,8 +81,21 @@ class ImmutableWrapper:
     the target will receive the wrapper.  This allows properties to work with
     overridden values.
 
+    ImmutableWrapper implements ``__getitem__``.  Any error raised by the
+    target is not handled.  The result of __getitem__ might be rewrapped (for
+    Odoo recordsets) in another ImmutableWrapper that inherits overrides and
+    the value of `wrap_callables` and `wrap_descriptors`.
+
+    ImmutableWrapper implements ``__bool__`` trying to call the underlying's
+    type ``__bool__`` with the wrapper as self.  If a TypeError occurrs while
+    calling the target's type ``__iter__``, fallback to ``bool(target)``.
+
     .. versionchanged:: 1.2.0  Add argument `wrap_descriptors`.
 
+    .. versionchanged:: 1.8.0  Add support for ``__getitem__``.
+
+    .. versionchanged:: 2.1.0  Implement ``__bool__``.
+
     """
 
     def __new__(
@@ -113,6 +126,10 @@ class ImmutableWrapper:
         ] = wrap_descriptors
         return result
 
+    def __getitem__(self, key):
+        item = self.__target[key]  # let errors go
+        return self.__maybe_rewrap(self, item, keep_overrides=True)
+
     def __getattr__(self, attr):
         from xotl.tools.symbols import Unset
 
@@ -130,6 +147,40 @@ class ImmutableWrapper:
                         res = Unset
         if res is Unset:
             res = getattr(self.__target, attr)
+        res = self.__maybe_rewrap(self, res, keep_overrides=False)
+        self.__cache[attr] = res
+        return res
+
+    def __bool__(self):
+        if type(self.__target) not in (int, float):
+            # int and float will raise a TypeError, so avoid the call.
+            method = getattr(type(self.__target), "__bool__", None)
+        else:
+            method = None
+        if method:
+            try:
+                return method(self)
+            except TypeError:
+                pass
+        return bool(self.__target)
+
+    def __setattr__(self, attr, value):
+        raise TypeError(
+            "Cannot mutate an immutable wrapped object.  Use method 'replace'."
+        )
+
+    def replace(self, **attrs):
+        """Return a new wrapper of the same object with updates."""
+        overrides = dict(self.__overrides, **attrs)
+        return ImmutableWrapper(
+            self.__target,
+            overrides=overrides,
+            wrap_callables=self.__wrap_callables,
+            wrap_descriptors=self.__wrap_descriptors,
+        )
+
+    @classmethod
+    def __maybe_rewrap(cls, self, res, keep_overrides):
         if (
             self.__wrap_callables
             and callable(res)
@@ -139,27 +190,21 @@ class ImmutableWrapper:
             # fuction so that `self` in the method is the ImmutableWrapper.
             res = partial(res.__func__, self)
         if isinstance(res, BaseModel):
-            res = ImmutableWrapper(res, wrap_callables=self.__wrap_callables)
-        self.__cache[attr] = res
+            if not keep_overrides:
+                res = ImmutableWrapper(
+                    res,
+                    wrap_callables=self.__wrap_callables,
+                    wrap_descriptors=self.__wrap_descriptors,
+                )
+            else:
+                res = ImmutableWrapper(
+                    res,
+                    overrides=self.__overrides,
+                    wrap_callables=self.__wrap_callables,
+                    wrap_descriptors=self.__wrap_descriptors,
+                )
         return res
 
-    def __setattr__(self, attr, value):
-        raise TypeError(
-            "Cannot mutate an immutable wrapped object.  Use method 'replace'."
-        )
-
-    def replace(self, **attrs):
-        """Return a new wrapper of the same object with updates.
-
-        """
-        overrides = dict(self.__overrides, **attrs)
-        return ImmutableWrapper(
-            self.__target,
-            overrides=overrides,
-            wrap_callables=self.__wrap_callables,
-            wrap_descriptors=self.__wrap_descriptors,
-        )
-
     # IMPORTANT: The __cache can't be part of the hash nor of eq because is
     # just an optimization and not a part of the *identity* of the object.
     #
