@@ -6,15 +6,14 @@
 #
 # This is free software; you can do what the LICENCE file allows you to.
 #
-from enum import Enum
 from dataclasses import dataclass
-from typing import Optional, Generic, Tuple, List, TypeVar, Type
+from enum import Enum
+from typing import Generic, List, Optional, Tuple, Type, TypeVar
 
-
-from xotl.tools.symbols import Undefined
 from xotl.tools.infinity import Infinity
+from xotl.tools.symbols import Undefined
 
-from .types import OrdTypeClass, EqTypeClass
+from .types import EqTypeClass, OrdTypeClass
 
 TEq = TypeVar("TEq", bound=EqTypeClass)
 TOrd = TypeVar("TOrd", bound=OrdTypeClass)
@@ -82,9 +81,7 @@ class Range(Generic[TOrd]):
     def new_open(
         cls, lowerbound: Optional[TOrd], upperbound: Optional[TOrd]
     ) -> "Range[TOrd]":
-        """Return an open range.
-
-        """
+        """Return an open range."""
         lb = Bound.normalized_lower_bound(lowerbound, Excluded)
         ub = Bound.normalized_upper_bound(upperbound, Excluded)
         return Range(lb, ub)
@@ -93,9 +90,7 @@ class Range(Generic[TOrd]):
     def new_open_left(
         cls, lowerbound: Optional[TOrd], upperbound: Optional[TOrd]
     ) -> "Range[TOrd]":
-        """Return a range open on the lower boundary and possibly closed in the upper boundary.
-
-        """
+        """Return a range open on the lower boundary and possibly closed in the upper boundary."""
         lb = Bound.normalized_lower_bound(lowerbound, Excluded)
         ub = Bound.normalized_upper_bound(upperbound, Included)
         return Range(lb, ub)
@@ -104,9 +99,7 @@ class Range(Generic[TOrd]):
     def new_open_right(
         cls, lowerbound: Optional[TOrd], upperbound: Optional[TOrd]
     ) -> "Range[TOrd]":
-        """Return a range possibly closed on the lower boundary and open in the upper boundary.
-
-        """
+        """Return a range possibly closed on the lower boundary and open in the upper boundary."""
         lb = Bound.normalized_lower_bound(lowerbound, Included)
         ub = Bound.normalized_upper_bound(upperbound, Excluded)
         return Range(lb, ub)
@@ -234,9 +227,7 @@ class Range(Generic[TOrd]):
         )
 
     def join(*ranges_: "Range[TOrd]") -> Tuple["Range[TOrd]", ...]:
-        """Return several disjoint ranges that describe the union of `ranges`.
-
-        """
+        """Return several disjoint ranges that describe the union of `ranges`."""
         # The join of `Range(Excluded(a), b)` with `Range(Included(a),
         # c)` must include a despite the order.  So we need order by
         # lowerbound and type.
@@ -346,9 +337,7 @@ class Range(Generic[TOrd]):
 
     @property
     def sample(self) -> Optional[TOrd]:
-        """Return a member of the range.  Return None if the range is empty or OPEN.
-
-        """
+        """Return a member of the range.  Return None if the range is empty or OPEN."""
         if self.empty or self.kind == RangeKind.OPEN:
             # There's no general way to get a sample from an OPEN range.
             return None
